==> pegasus-merchandise-api-2.6.8-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpListpageVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.pegasus.merchandise.enums.SoldOutProdDisplayEnum;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2018/12/6.
 */
public class OpListpageVO implements Serializable {
    private static final long serialVersionUID = 1L;
    private Integer id;
    private String title;
    private String note;
    private String status;
    private String pcBannerUrl;
    private String appBannerUrl;
    private String updateUsername;
    private String updateNickname;
    private Date createTime;
    private Date updateTime;
    private List<OpListpageProdVO> prodList;


    private Integer pcBannerWidth;
    private Integer pcBannerHeight;



    private Integer appBannerWidth;
    private Integer appBannerHeight;
    private SoldOutProdDisplayEnum soldOutProdDisplayEnum;
    private String shoppingShareUrl;


    private Integer shoppingShareWidth;
    private Integer shoppingShareHeight;
    private String  smallprogramShareUrl;




    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }


    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }


    public String getPcBannerUrl() {
        return pcBannerUrl;
    }

    public void setPcBannerUrl(String pcBannerUrl) {
        this.pcBannerUrl = pcBannerUrl;
    }

    public String getAppBannerUrl() {
        return appBannerUrl;
    }

    public void setAppBannerUrl(String appBannerUrl) {
        this.appBannerUrl = appBannerUrl;
    }

    public String getUpdateUsername() {
        return updateUsername;
    }

    public void setUpdateUsername(String updateUsername) {
        this.updateUsername = updateUsername;
    }

    public String getUpdateNickname() {
        return updateNickname;
    }

    public void setUpdateNickname(String updateNickname) {
        this.updateNickname = updateNickname;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<OpListpageProdVO> getProdList() {
        return prodList;
    }

    public void setProdList(List<OpListpageProdVO> prodList) {
        this.prodList = prodList;
    }

    public Integer getPcBannerWidth() {
        return pcBannerWidth;
    }

    public void setPcBannerWidth(Integer pcBannerWidth) {
        this.pcBannerWidth = pcBannerWidth;
    }

    public Integer getPcBannerHeight() {
        return pcBannerHeight;
    }

    public void setPcBannerHeight(Integer pcBannerHeight) {
        this.pcBannerHeight = pcBannerHeight;
    }

    public Integer getAppBannerWidth() {
        return appBannerWidth;
    }

    public void setAppBannerWidth(Integer appBannerWidth) {
        this.appBannerWidth = appBannerWidth;
    }

    public Integer getAppBannerHeight() {
        return appBannerHeight;
    }

    public void setAppBannerHeight(Integer appBannerHeight) {
        this.appBannerHeight = appBannerHeight;
    }

    public SoldOutProdDisplayEnum getSoldOutProdDisplayEnum() {
        return soldOutProdDisplayEnum;
    }

    public void setSoldOutProdDisplayEnum(SoldOutProdDisplayEnum soldOutProdDisplayEnum) {
        this.soldOutProdDisplayEnum = soldOutProdDisplayEnum;
    }

    public String getShoppingShareUrl() {
        return shoppingShareUrl;
    }

    public void setShoppingShareUrl(String shoppingShareUrl) {
        this.shoppingShareUrl = shoppingShareUrl;
    }


    public Integer getShoppingShareWidth() {
        return shoppingShareWidth;
    }

    public void setShoppingShareWidth(Integer shoppingShareWidth) {
        this.shoppingShareWidth = shoppingShareWidth;
    }


    public Integer getShoppingShareHeight() {
        return shoppingShareHeight;
    }

    public void setShoppingShareHeight(Integer shoppingShareHeight) {
        this.shoppingShareHeight = shoppingShareHeight;
    }

    public String getSmallprogramShareUrl() {
        return smallprogramShareUrl;
    }

    public void setSmallprogramShareUrl(String smallprogramShareUrl) {
        this.smallprogramShareUrl = smallprogramShareUrl;
    }


    @Override
    public String toString() {
       return "id=" + id + ",title=" + title + ",updateUsername=" + updateUsername;
    }
}

==> pegasus-merchandise-api-4.0.10-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpListpageVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.pegasus.merchandise.enums.SoldOutProdDisplayEnum;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2018/12/6.
 */
public class OpListpageVO implements Serializable {
    private static final long serialVersionUID = 1L;
    private Integer id;
    private String title;
    private String note;
    private String status;
    private String pcBannerUrl;
    private String appBannerUrl;
    private String updateUsername;
    private String updateNickname;
    private Date createTime;
    private Date updateTime;
    private List<OpListpageProdVO> prodList;


    private Integer pcBannerWidth;
    private Integer pcBannerHeight;



    private Integer appBannerWidth;
    private Integer appBannerHeight;
    private SoldOutProdDisplayEnum soldOutProdDisplayEnum;
    private String shoppingShareUrl;


    private Integer shoppingShareWidth;
    private Integer shoppingShareHeight;
    private String  smallprogramShareUrl;

    private Integer pcJumpType;
    private Integer appJumpType;
    private String pcJumpId;
    private String appJumpId;




    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }


    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }


    public String getPcBannerUrl() {
        return pcBannerUrl;
    }

    public void setPcBannerUrl(String pcBannerUrl) {
        this.pcBannerUrl = pcBannerUrl;
    }

    public String getAppBannerUrl() {
        return appBannerUrl;
    }

    public void setAppBannerUrl(String appBannerUrl) {
        this.appBannerUrl = appBannerUrl;
    }

    public String getUpdateUsername() {
        return updateUsername;
    }

    public void setUpdateUsername(String updateUsername) {
        this.updateUsername = updateUsername;
    }

    public String getUpdateNickname() {
        return updateNickname;
    }

    public void setUpdateNickname(String updateNickname) {
        this.updateNickname = updateNickname;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<OpListpageProdVO> getProdList() {
        return prodList;
    }

    public void setProdList(List<OpListpageProdVO> prodList) {
        this.prodList = prodList;
    }

    public Integer getPcBannerWidth() {
        return pcBannerWidth;
    }

    public void setPcBannerWidth(Integer pcBannerWidth) {
        this.pcBannerWidth = pcBannerWidth;
    }

    public Integer getPcBannerHeight() {
        return pcBannerHeight;
    }

    public void setPcBannerHeight(Integer pcBannerHeight) {
        this.pcBannerHeight = pcBannerHeight;
    }

    public Integer getAppBannerWidth() {
        return appBannerWidth;
    }

    public void setAppBannerWidth(Integer appBannerWidth) {
        this.appBannerWidth = appBannerWidth;
    }

    public Integer getAppBannerHeight() {
        return appBannerHeight;
    }

    public void setAppBannerHeight(Integer appBannerHeight) {
        this.appBannerHeight = appBannerHeight;
    }

    public SoldOutProdDisplayEnum getSoldOutProdDisplayEnum() {
        return soldOutProdDisplayEnum;
    }

    public void setSoldOutProdDisplayEnum(SoldOutProdDisplayEnum soldOutProdDisplayEnum) {
        this.soldOutProdDisplayEnum = soldOutProdDisplayEnum;
    }

    public String getShoppingShareUrl() {
        return shoppingShareUrl;
    }

    public void setShoppingShareUrl(String shoppingShareUrl) {
        this.shoppingShareUrl = shoppingShareUrl;
    }


    public Integer getShoppingShareWidth() {
        return shoppingShareWidth;
    }

    public void setShoppingShareWidth(Integer shoppingShareWidth) {
        this.shoppingShareWidth = shoppingShareWidth;
    }


    public Integer getShoppingShareHeight() {
        return shoppingShareHeight;
    }

    public void setShoppingShareHeight(Integer shoppingShareHeight) {
        this.shoppingShareHeight = shoppingShareHeight;
    }

    public String getSmallprogramShareUrl() {
        return smallprogramShareUrl;
    }

    public void setSmallprogramShareUrl(String smallprogramShareUrl) {
        this.smallprogramShareUrl = smallprogramShareUrl;
    }

    public Integer getPcJumpType() {
        return pcJumpType;
    }

    public void setPcJumpType(Integer pcJumpType) {
        this.pcJumpType = pcJumpType;
    }

    public Integer getAppJumpType() {
        return appJumpType;
    }

    public void setAppJumpType(Integer appJumpType) {
        this.appJumpType = appJumpType;
    }

    public String getPcJumpId() {
        return pcJumpId;
    }

    public void setPcJumpId(String pcJumpId) {
        this.pcJumpId = pcJumpId;
    }

    public String getAppJumpId() {
        return appJumpId;
    }

    public void setAppJumpId(String appJumpId) {
        this.appJumpId = appJumpId;
    }


    @Override
    public String toString() {
       return "id=" + id + ",title=" + title + ",updateUsername=" + updateUsername;
    }
}
